# $Id: autogen.sh,v 1.1.1.2 2004/07/20 16:30:34 rousseau Exp $

set -x

rm -f configure Makefile Makefile.in config.h.in src/Makefile.in src/Makefile
aclocal

libtoolize --force --copy

autoheader
automake --add-missing --foreign
autoconf

